@@ -61,8 +61,10 @@ class Lattice(object):
 
     def lat_lengths(self):
         """Return lattice vectors' lengths."""
-        return [round(i, 6) for i in (
-                np.sqrt(np.sum(self._lat ** 2, axis=1)).tolist())]
+        return [
+            round(i, 6)
+            for i in (np.sqrt(np.sum(self._lat ** 2, axis=1)).tolist())
+        ]
         # return [round(np.linalg.norm(v), 6) for v in self._lat]
 
     @property
@@ -133,8 +135,14 @@ class Lattice(object):
     @property
     def parameters(self):
         """Return lattice vector angles in radians or degree."""
-        return [self.a, self.b, self.c,
-                self.angles[0], self.angles[1], self.angles[2]]
+        return [
+            self.a,
+            self.b,
+            self.c,
+            self.angles[0],
+            self.angles[1],
+            self.angles[2],
+        ]
 
     @staticmethod
     def from_parameters(a, b, c, alpha, beta, gamma):
@@ -184,12 +192,13 @@ class Lattice(object):
         """Construct rhombohedral Lattice."""
         return Lattice.from_parameters(a, a, a, alpha, alpha, alpha)
 
-    def as_dict(self):
+    def to_dict(self):
         """Return lattice parameter information as a dictionary."""
         d = OrderedDict()
         d["matrix"] = self.matrix
         return d
 
+    @classmethod
     def from_dict(self, d):
         """Construct Lattice from lattice matrix dictionary."""
         return Lattice(lattice_mat=d["matrix"])
@@ -235,7 +244,8 @@ class Lattice(object):
         Adapted from pymatgen.
         """
         recp_len = np.array(self.reciprocal_lattice().lat_lengths()) / (
-            2 * np.pi)
+            2 * np.pi
+        )
         nmax = float(r) * recp_len + 0.01
 
         # Get the fractional coordinates of the center of the sphere
@@ -302,8 +312,9 @@ class Lattice(object):
         ]
         c_a, c_b, c_c = (cart[i] for i in inds)
         f_a, f_b, f_c = (frac[i] for i in inds)
-        l_a, l_b, l_c = (np.sum(c ** 2, axis=-1)
-                         ** 0.5 for c in (c_a, c_b, c_c))
+        l_a, l_b, l_c = (
+            np.sum(c ** 2, axis=-1) ** 0.5 for c in (c_a, c_b, c_c)
+        )
 
         def get_angles(v1, v2, l1, l2):
             x = np.inner(v1, v2) / l1[:, None] / l2
@@ -381,9 +392,10 @@ class Lattice(object):
                 if q != 0:
                     # Reduce the k-th basis vector.
                     a[:, k - 1] = a[:, k - 1] - q * a[:, i - 1]
-                    mapping[:, k - 1] = mapping[:, k - 1
-                                                ] - q * mapping[:, i - 1]
-                    uu = list(u[i - 1, 0: (i - 1)])
+                    mapping[:, k - 1] = (
+                        mapping[:, k - 1] - q * mapping[:, i - 1]
+                    )
+                    uu = list(u[i - 1, 0 : (i - 1)])
                     uu.append(1)
                     # Update the GS coefficients.
                     u[k - 1, 0:i] = u[k - 1, 0:i] - q * np.array(uu)
@@ -407,11 +419,11 @@ class Lattice(object):
 
                 # Update the Gram-Schmidt coefficients
                 for s in range(k - 1, k + 1):
-                    u[s - 1, 0: (s - 1)] = (
-                        dot(a[:, s - 1].T, b[:, 0: (s - 1)]) / m[0: (s - 1)]
+                    u[s - 1, 0 : (s - 1)] = (
+                        dot(a[:, s - 1].T, b[:, 0 : (s - 1)]) / m[0 : (s - 1)]
                     )
                     b[:, s - 1] = a[:, s - 1] - dot(
-                        b[:, 0: (s - 1)], u[s - 1, 0: (s - 1)].T
+                        b[:, 0 : (s - 1)], u[s - 1, 0 : (s - 1)].T
                     )
                     m[s - 1] = dot(b[:, s - 1], b[:, s - 1])
 
@@ -419,11 +431,12 @@ class Lattice(object):
                     k -= 1
                 else:
                     # We have to do p/q, so do lstsq(q.T, p.T).T instead.
-                    p = dot(a[:, k:3].T, b[:, (k - 2): k])
-                    q = np.diag(m[(k - 2): k])
-                    result = np.linalg.lstsq(q.T, p.T,
-                                             rcond=None)[0].T  # type: ignore
-                    u[k:3, (k - 2): k] = result
+                    p = dot(a[:, k:3].T, b[:, (k - 2) : k])
+                    q = np.diag(m[(k - 2) : k])
+                    result = np.linalg.lstsq(q.T, p.T, rcond=None)[
+                        0
+                    ].T  # type: ignore
+                    u[k:3, (k - 2) : k] = result
 
         return a.T, mapping.T
 
