@@ -32,6 +32,19 @@ class Poscar(object):
         with open(filename, "r") as f:
             return Poscar.from_string(f.read())
 
+    def to_dict(self):
+        """Convert Poscar object to a dictionary."""
+        d = OrderedDict()
+        d["atoms"] = self.atoms.to_dict()
+        d["comment"] = self.comment
+        return d
+
+    @classmethod
+    def from_dict(self, d={}):
+        """Construct Poscar object from a dictionary."""
+        print("dddd", d)
+        return Poscar(atoms=Atoms.from_dict(d["atoms"]), comment=d["comment"])
+
     def write_file(self, filename):
         """Write the Poscar object to a file."""
         f = open(filename, "w")
@@ -220,6 +233,7 @@ class Incar(object):
         """Convert into dictionary."""
         return self._tags
 
+    @classmethod
     def from_dict(self, data={}):
         """Construct from dictionary."""
         return Incar(tags=data)
@@ -290,28 +304,49 @@ class Potcar(object):
         elements=[],
         pot_type="POT_GGA_PAW_PBE",
         pot_json_path="",
-        potcar_strings={},
+        potcar_strings=[],
     ):
-        """Initialize the Potcar class."""
+        """
+        Initialize the Potcar class.
+
+        POTCAR file contains the pseudopotential for each
+        atomic species used in the calculation.
+        Args:
+            elements: atomic elements.
+
+            pot_type: Type of pseudopotential.
+            Look for VASP provided PSPs.
+            JARVIS_VASP_PSP_DIR should be in the path.
+
+            pot_json_path: Path to dictionary of chemical elements along with
+            their orbitals taken into conisideration, e.g. V_pv.
+
+            potcar_strings: One can directly provide
+            the above mentioned strings.
+        """
         self._elements = elements
         self._pot_type = pot_type
         self._potcar_strings = potcar_strings
         self._pot_json_path = pot_json_path
 
-        if self._potcar_strings == {}:
+        if self._potcar_strings == []:
             pot_json_file = str(
                 os.path.join(os.path.dirname(__file__), "default_potcars.json")
             )
+            self._pot_json_path = pot_json_file
             pot_json = open(pot_json_file, "r")
             pot_json_selected = json.load(pot_json)
             pot_json.close()
-            potcar_strings = OrderedDict()
+            potcar_strings = []  # OrderedDict()
             for i in self._elements:
-                for j, k in pot_json_selected.items():
-                    if i == j:
-                        potcar_strings.setdefault(i, k)
+                potcar_strings.append(pot_json_selected[i])
+                # for j, k in pot_json_selected.items():
+                #    if i == j:
+                #        potcar_strings.setdefault(i, k)
             self._potcar_strings = potcar_strings
-            if len(self._elements) != len(self._potcar_strings.keys()):
+            print("self._elements", self._elements)
+            print("self._potcar_strings", self._potcar_strings)
+            if len(self._elements) != len(self._potcar_strings):
                 raise ValueError(
                     "Number of elements is not same as potcar_strings",
                     self._elements,
@@ -321,17 +356,33 @@ class Potcar(object):
             pot_json = open(self._pot_json_path, "r")
             pot_json_selected = json.load(pot_json)
             pot_json.close()
-            potcar_strings = OrderedDict()
-            for i, j in pot_json_selected.items():
-                if i in self._elements:
-                    potcar_strings.setdefault(i, j)
             self._potcar_strings = potcar_strings
-            if len(self._elements) != len(self._potcar_strings.keys()):
+            if len(self._elements) != len(self._potcar_strings):
                 msg = "Number of elements not same as potcar_strings"
                 raise ValueError(msg)
 
-    def catenate_potcar_files(self, destination_filename="POTCAR",
-                              filenames=[]):
+    @classmethod
+    def from_dict(self, d={}):
+        """Build class from a dictionary."""
+        return Potcar(
+            elements=d["elements"],
+            pot_type=d["pot_type"],
+            pot_json_path=d["pot_json_path"],
+            potcar_strings=d["potcar_strings"],
+        )
+
+    def to_dict(self):
+        """Convert to a dictionary."""
+        d = OrderedDict()
+        d["elements"] = np.array(self._elements).tolist()
+        d["pot_type"] = self._pot_type
+        d["pot_json_path"] = self._pot_json_path
+        d["potcar_strings"] = np.array(self._potcar_strings).tolist()
+        return d
+
+    def catenate_potcar_files(
+        self, destination_filename="POTCAR", filenames=[]
+    ):
         """Catenate potcars of sifferent elements."""
         with open(destination_filename, "w") as outfile:
             for fname in filenames:
@@ -345,7 +396,7 @@ class Potcar(object):
         vasp_dir = str(os.environ["JARVIS_VASP_PSP_DIR"])
         vasp_psp_dir = str(os.path.join(vasp_dir, self._pot_type))
         potcar_strings = self._potcar_strings
-        for i, j in potcar_strings.items():
+        for j in potcar_strings:
             tmp = os.path.join(vasp_psp_dir, j, "POTCAR")
             pot_files.append(tmp)
         return pot_files
@@ -353,8 +404,9 @@ class Potcar(object):
     def write_file(self, filename="POTCAR"):
         """Write POTCAR file."""
         pot_files = self.list_potcar_files()
-        self.catenate_potcar_files(destination_filename=filename,
-                                   filenames=pot_files)
+        self.catenate_potcar_files(
+            destination_filename=filename, filenames=pot_files
+        )
 
     def __repr__(self):
         """Represent Potcar."""
@@ -414,8 +466,9 @@ class Kpoints(object):
         for i, j in zip(kp_labels, kp_labels_points):
             labels[j] = i
         all_kp = np.array(all_kp, dtype="float")
-        kpoints = Kpoints3D(kpoints=all_kp,
-                            labels=labels, kpoint_mode="linemode")
+        kpoints = Kpoints3D(
+            kpoints=all_kp, labels=labels, kpoint_mode="linemode"
+        )
         return kpoints
 
 
